@@ -467,12 +467,12 @@ void ModelTest::data()
     }
 
     // General Purpose roles that should return a QColor
-    QVariant colorVariant = model->data(model->index(0, 0), Qt::BackgroundColorRole);
+    QVariant colorVariant = model->data(model->index(0, 0), Qt::BackgroundRole);
     if (colorVariant.isValid()) {
         Q_ASSERT(colorVariant.canConvert<QColor>());
     }
 
-    colorVariant = model->data(model->index(0, 0), Qt::TextColorRole);
+    colorVariant = model->data(model->index(0, 0), Qt::ForegroundRole);
     if (colorVariant.isValid()) {
         Q_ASSERT(colorVariant.canConvert<QColor>());
     }
@@ -564,8 +564,7 @@ void ModelTest::layoutChanged()
     changing.clear();
 }
 
-void ModelTest::rowsAboutToBeMoved(const QModelIndex &srcParent, int start, int end,
-                                   const QModelIndex &destParent, int destinationRow)
+void ModelTest::rowsAboutToBeMoved(const QModelIndex &srcParent, int start, int end, const QModelIndex &destParent, int destinationRow)
 {
     qDebug() << "rowsAboutToBeMoved" << srcParent << start << end << destParent << destinationRow;
     Changing cs;
@@ -583,8 +582,7 @@ void ModelTest::rowsAboutToBeMoved(const QModelIndex &srcParent, int start, int
     insert.push(cd);
 }
 
-void ModelTest::rowsMoved(const QModelIndex &srcParent, int start, int end,
-                          const QModelIndex &destParent, int destinationRow)
+void ModelTest::rowsMoved(const QModelIndex &srcParent, int start, int end, const QModelIndex &destParent, int destinationRow)
 {
     qDebug() << "rowsMoved" << srcParent << start << end << destParent << destinationRow;
 
